Generates simulated NHS patients
sim_patients(n_rows = 10, start_date = NULL)A data.frame representing an empty waiting list with the following columns:
Date. Referral date; all values are NA.
Date. Removal date; all values are NA.
Date. Patient withdrawal date; all values are
NA
Numeric. Waiting list priority level, from 1 (most urgent) to 4 (least urgent).
Numeric. Target number of days the patient should wait at the assigned priority level (e.g., 28 days for priority 2)
Character. Patient name in the format
"Last, First".
Date. Date of birth.
Integer. Patient identifier, up to 100,000,000.
Character. One-letter code representing the specialty of the procedure.
Character. Full name of the specialty associated with the procedure.
Character. OPCS-4 code of the selected procedure.
Character. Name of the selected procedure.
Character. Consultant name in the format
"Last, First".
Number of rows/patients to generate
Start date (needed to generate patient ages)